#ifndef _MENUDIRECTOR_H
#define _MENUDIRECTOR_H 1

#include <vdr/channels.h>
#include <vdr/osdbase.h>

#include "arghdirector.h"

class cMenuDirector;

//***************************************************************************
// 
//***************************************************************************

class cMenuDirectorItemBase : public cOsdItem
{
   public:

      cMenuDirectorItemBase(const cEvent* aEvent, int aHeadline, const char* Text = "");
      int isHeadline()             { return headline; }
      const cEvent* Event()        { return mEvent; }

   protected:

      int headline;
      const cEvent* mEvent;
};

//***************************************************************************
// 
//***************************************************************************

class cMenuDirectorItemHeadline : public cMenuDirectorItemBase
{
   public:

      cMenuDirectorItemHeadline(const cEvent* aEvent, const char *Text);
};

//***************************************************************************
// 
//***************************************************************************

class cMenuDirectorItem : public cMenuDirectorItemBase
{
   public:

      cMenuDirectorItem(cMenuDirector* menu, const cChannel* channel, 
                        const cEvent* event = 0, 
                        int details = false, int next = false);
      virtual ~cMenuDirectorItem() {}

      const cChannel* Channel()    { return mChannel; }
      int Update(int force);

   private:

      const cChannel* mChannel;
      cMenuDirector* mMenu;
      int mDetails;
      int mNext;
      int lastTimerMatch;
};

//***************************************************************************
// 
//***************************************************************************

class cMenuDirector : public cOsdMenu
{
   public:

      cMenuDirector(const char* title, cMenuDirectorData* data, 
                    int aShowStartTimes = false, const cEvent* aStartEvent = 0);
      virtual ~cMenuDirector();

      const char* hotKey(const char *s) { return hk(s); }
      virtual eOSState ProcessKey(eKeys Key);
      void Update();

      static cOsdMenu* Create(const char* title, cOsdProxyData* data);
      static void Release();
      static void ChannelSwitchNonOsd(int direction);
      static eOSState KeyHandlerFunction(eKeys Key);

      const char* MenuKind() { return "MenuArghDirector"; }

   private:

      const cChannel* mCurrentChannel;
      const cEvent* mCurrentEvent;
      int showStartTimes;
      const cEvent* startEvent;

      const cEvent* currentEventOf(const cChannel* channel);
      void DetermineReferenceChannel();
      cOsdItem* AddEpgItem(const cEvent* event);
      void SelectCurrentChannel();
      cChannel* GetChannel(int Index);
      void SwitchToChannel(const cChannel* channel);
      eOSState Record(cMenuDirectorItem* item);
      void SetHelpKeys(cMenuDirectorItem* item);

      // statics

      static cMenuDirectorData* mData;
      static const cChannel* mReferenceChannel;
      static void ChannelSwitchNonOsd(const cChannel* channel);
      static const cLinkChannels* GetLinkChannelsOutOfChannel(const cChannel* channel);
      static const cChannel* GetRefChannelOutOfChannel(const cChannel* channel);

};

//***************************************************************************
#endif
